@@ -1,8 +1,10 @@
 import coloredlogs, logging
 
 logger=logging.getLogger(__name__)
+
 coloredlogs.install(level='DEBUG',logger=logger)
-logger.debug("Hola Keepcoders")
+
+logger.info("Prmera Practica CI/CD")
 
 def add_one(number):
     return number+1
